summaryrefslogtreecommitdiffstats
path: root/src/occ_405/amec/amec_pcap.c
diff options
context:
space:
mode:
authorShawn McCarney <shawnmm@us.ibm.com>2017-04-25 15:19:48 -0500
committerChristopher J. Cain <cjcain@us.ibm.com>2017-04-27 17:39:49 -0400
commitb227f22726bc2c51c65966c461f96b450875edd3 (patch)
tree3063a295560bad8bf22f30445f4a313b0ab13fde /src/occ_405/amec/amec_pcap.c
parentc36fa46c1e2ab003f0b12c0e52ad7301b826ea38 (diff)
downloadtalos-occ-b227f22726bc2c51c65966c461f96b450875edd3.tar.gz
talos-occ-b227f22726bc2c51c65966c461f96b450875edd3.zip
OCC: Non-GPU Sensors to main memory: Phase 1
Performed the following sensor renames required by this RTC story: FREQA4MSP0Cy -> FREQACy UTIL4MSP0Cy -> UTILCy PWR250US -> PWRSYS PWR250USP0 -> PWRPROC Also renamed the following related symbols: * Associated sensor_t field names in the amec_sys_t data structure * Mini-sensor field names * Parent sensors that contain a vector iterating over renamed sensors Change-Id: I1e9e17661e5730ed6309fc7617c61bd973d2e44f Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/39772 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: William A. Bryan <wilbryan@us.ibm.com> Reviewed-by: Martha Broyles <mbroyles@us.ibm.com> Reviewed-by: Christopher J. Cain <cjcain@us.ibm.com>
Diffstat (limited to 'src/occ_405/amec/amec_pcap.c')
-rwxr-xr-xsrc/occ_405/amec/amec_pcap.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/occ_405/amec/amec_pcap.c b/src/occ_405/amec/amec_pcap.c
index b198941..81b75ac 100755
--- a/src/occ_405/amec/amec_pcap.c
+++ b/src/occ_405/amec/amec_pcap.c
@@ -98,8 +98,8 @@ void amec_pcap_calc(void)
/* Local Variables */
/*------------------------------------------------------------------------*/
bool l_oversub_state = 0;
- uint16_t l_node_pwr = AMECSENSOR_PTR(PWR250US)->sample;
- uint16_t l_p0_pwr = AMECSENSOR_PTR(PWR250USP0)->sample;
+ uint16_t l_node_pwr = AMECSENSOR_PTR(PWRSYS)->sample;
+ uint16_t l_p0_pwr = AMECSENSOR_PTR(PWRPROC)->sample;
int32_t l_avail_power = 0;
uint16_t mem_pwr_diff = 0;
uint32_t l_proc_fraction = 0;
@@ -143,7 +143,7 @@ void amec_pcap_calc(void)
l_proc_fraction = ((uint32_t)(l_p0_pwr) << 16)/l_node_pwr;
if(L_apss_error_traced)
{
- TRAC_ERR("PCAP: PWR250US sensor is no longer 0.");
+ TRAC_ERR("PCAP: PWRSYS sensor is no longer 0.");
L_apss_error_traced = FALSE;
}
@@ -192,7 +192,7 @@ void amec_pcap_calc(void)
{
if(!L_apss_error_traced)
{
- TRAC_ERR("PCAP: PWR250US sensor is showing a value of 0.");
+ TRAC_ERR("PCAP: PWRSYS sensor is showing a value of 0.");
L_apss_error_traced = TRUE;
}
}
@@ -238,7 +238,7 @@ void amec_pcap_controller(void)
/* Code */
/*------------------------------------------------------------------------*/
- l_power_avail = g_amec->pcap.active_proc_pcap - AMECSENSOR_PTR(PWR250USP0)->sample;
+ l_power_avail = g_amec->pcap.active_proc_pcap - AMECSENSOR_PTR(PWRPROC)->sample;
if(l_proc_pcap_vote > g_amec->proc[0].pwr_votes.nom_pcap_fmin)
{
@@ -304,9 +304,9 @@ void amec_ppb_fmax_calc(void)
if(OCC_MASTER == G_occ_role)
{
//Power available is the ActiveNodePower - PowerDropThreshold - ActualPwr
- l_power_avail = g_amec->pcap.active_node_pcap - PDROP_THRESH - AMECSENSOR_PTR(PWR250US)->sample;
+ l_power_avail = g_amec->pcap.active_node_pcap - PDROP_THRESH - AMECSENSOR_PTR(PWRSYS)->sample;
- //Note: The PWR250US value is read over the SPI bus, which has no error
+ //Note: The PWRSYS value is read over the SPI bus, which has no error
//detection. In order to prevent a single bad SPI transfer from causing
//OCC to lower nominal core frequencies, we require the power to be over
//the pcap for PPB_NOM_DROP_DELAY ticks before lowering PPB Fmax below
OpenPOWER on IntegriCloud